@@ -15,7 +15,7 @@
 //!
 //! ```toml
 //! [dependencies]
-//! static_assertions = "0.3.1"
+//! static_assertions = "0.3.2"
 //! ```
 //!
 //! and this to your crate root (`main.rs` or `lib.rs`):
@@ -64,7 +64,7 @@
 //!
 //! ```toml
 //! [dependencies.static_assertions]
-//! version  = "0.3.1"
+//! version  = "0.3.2"
 //! features = ["nightly"]
 //! ```
 //!
@@ -117,7 +117,7 @@
 //! [compile-time]: https://en.wikipedia.org/wiki/Compile_time
 //! [`Cargo.toml`]: https://doc.rust-lang.org/cargo/reference/manifest.html
 
-#![doc(html_root_url = "https://docs.rs/static_assertions/0.3.1")]
+#![doc(html_root_url = "https://docs.rs/static_assertions/0.3.2")]
 #![doc(html_logo_url = "https://raw.githubusercontent.com/nvzqz/static-assertions-rs/assets/Icon.png")]
 
 #![no_std]
@@ -129,7 +129,9 @@ pub extern crate core as _core;
 
 mod assert_cfg;
 mod assert_eq_size;
+mod assert_eq_type;
 mod assert_fields;
 mod assert_impl;
+mod assert_ne_type;
 mod assert_obj_safe;
 mod const_assert;
